#[non_exhaustive]pub enum CreateCustomPluginError {
BadRequestException(BadRequestException),
ConflictException(ConflictException),
ForbiddenException(ForbiddenException),
InternalServerErrorException(InternalServerErrorException),
NotFoundException(NotFoundException),
ServiceUnavailableException(ServiceUnavailableException),
TooManyRequestsException(TooManyRequestsException),
UnauthorizedException(UnauthorizedException),
Unhandled(Unhandled),
}Expand description
Error type for the CreateCustomPluginError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BadRequestException(BadRequestException)
HTTP Status Code 400: Bad request due to incorrect input. Correct your request and then retry it.
ConflictException(ConflictException)
HTTP Status Code 409: Conflict. A resource with this name already exists. Retry your request with another name.
ForbiddenException(ForbiddenException)
HTTP Status Code 403: Access forbidden. Correct your credentials and then retry your request.
InternalServerErrorException(InternalServerErrorException)
HTTP Status Code 500: Unexpected internal server error. Retrying your request might resolve the issue.
NotFoundException(NotFoundException)
HTTP Status Code 404: Resource not found due to incorrect input. Correct your request and then retry it.
HTTP Status Code 503: Service Unavailable. Retrying your request in some time might resolve the issue.
TooManyRequestsException(TooManyRequestsException)
HTTP Status Code 429: Limit exceeded. Resource limit reached.
HTTP Status Code 401: Unauthorized request. The provided credentials couldn't be validated.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl CreateCustomPluginError
impl CreateCustomPluginError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the CreateCustomPluginError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the CreateCustomPluginError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_bad_request_exception(&self) -> bool
pub fn is_bad_request_exception(&self) -> bool
Returns true if the error kind is CreateCustomPluginError::BadRequestException.
Sourcepub fn is_conflict_exception(&self) -> bool
pub fn is_conflict_exception(&self) -> bool
Returns true if the error kind is CreateCustomPluginError::ConflictException.
Sourcepub fn is_forbidden_exception(&self) -> bool
pub fn is_forbidden_exception(&self) -> bool
Returns true if the error kind is CreateCustomPluginError::ForbiddenException.
Sourcepub fn is_internal_server_error_exception(&self) -> bool
pub fn is_internal_server_error_exception(&self) -> bool
Returns true if the error kind is CreateCustomPluginError::InternalServerErrorException.
Sourcepub fn is_not_found_exception(&self) -> bool
pub fn is_not_found_exception(&self) -> bool
Returns true if the error kind is CreateCustomPluginError::NotFoundException.
Returns true if the error kind is CreateCustomPluginError::ServiceUnavailableException.
Sourcepub fn is_too_many_requests_exception(&self) -> bool
pub fn is_too_many_requests_exception(&self) -> bool
Returns true if the error kind is CreateCustomPluginError::TooManyRequestsException.
Returns true if the error kind is CreateCustomPluginError::UnauthorizedException.