#[non_exhaustive]pub struct CreateCustomPluginInput {
pub content_type: Option<CustomPluginContentType>,
pub description: Option<String>,
pub location: Option<CustomPluginLocation>,
pub name: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.content_type: Option<CustomPluginContentType>The type of the plugin file.
description: Option<String>A summary description of the custom plugin.
location: Option<CustomPluginLocation>Information about the location of a custom plugin.
name: Option<String>The name of the custom plugin.
The tags you want to attach to the custom plugin.
Implementations
Sourceimpl CreateCustomPluginInput
impl CreateCustomPluginInput
Sourcepub fn content_type(&self) -> Option<&CustomPluginContentType>
pub fn content_type(&self) -> Option<&CustomPluginContentType>
The type of the plugin file.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A summary description of the custom plugin.
Sourcepub fn location(&self) -> Option<&CustomPluginLocation>
pub fn location(&self) -> Option<&CustomPluginLocation>
Information about the location of a custom plugin.
The tags you want to attach to the custom plugin.
Sourceimpl CreateCustomPluginInput
impl CreateCustomPluginInput
Sourcepub fn builder() -> CreateCustomPluginInputBuilder
pub fn builder() -> CreateCustomPluginInputBuilder
Creates a new builder-style object to manufacture CreateCustomPluginInput.